import time
from ConfigParser import ConfigParser

import pygame

def ticks():
    return int(time.time() * 1000)

class MarqueeConfig(ConfigParser):
    def _delim_split(self, value, delimeter=','):
        return [word.strip() for word in value.split(delimeter)]
    
    def get_list(self, section, option, delimeter=','):
        value = self.get(section, option)
        the_list = self._delim_split(value, delimeter=delimeter)
        the_list = [part for part in the_list if part]
        return the_list
    
    def get_xy(self, section, option, numtype=int):
        items = self.get_list(section, option)
        items = [numtype(x) for x in items]
        return tuple(items)
    
        
    def get_scenes(self):
        return self.get_list('Marquee', 'order')

    def get_scene_data(self, scene):
        data = {}
        options = self.options(scene)
        for option in options:
            data[option] = self.get(scene, option)
        return data

    def get_color(self, section, option):
        value = self.get(section, option)
        if value.startswith('#'):
            return pygame.color.Color(value)
        elif value.startswith('0x'):
            return pygame.color.Color(value)
        elif ',' in value:
            triplet = [int(part) for part in self._delim_split(value)]
            return pygame.color.Color(tuple(triplet))
        else:
            return pygame.color.Color(value)
        
    def get_color_orig(self, name):
        section = 'NamedColors'
        value = self.get(section, name)
        if value.startswith('#'):
            return pygame.color.Color(value)
        elif value.startswith('0x'):
            return pygame.color.Color(value)
        elif ',' in value:
            triplet = [int(part) for part in self._delim_split(value)]
            return tuple(triplet)
        else:
            return pygame.color.Color(value)

    def _get_color(self, name):
        color_value = self._get_color(name)
        return pygame.color.Color(color_value)
    
    def get_speed(self, scene):
        try:
            return [int(x) for x in self.get_list(scene, 'speed')]
        except ValueError:
            return [float(x) for x in self.get_list(scene, 'speed')]
            
config = MarqueeConfig()

config.read(['marquee.ini'])

