import pygame

from base import config
from scene import Scene

def slideshow_loop(screen):
    scene_list = config.get_scenes()
    lowmem = config.getboolean('Marquee', 'lowmem')
    # If not using lowmem, go ahead and preload
    # all the scenes in memory
    if not lowmem:
        scene_set = set(scene_list)
        scenes = {}
        for scene in scene_set:
            scenes[scene] = Scene(screen, scene)
            scenes[scene].initialize()
    # set index to -1 to start with list[0] since
    # index is incremented at the beginning of
    # the loop.
    index = -1
    while True:
        index += 1
        if index == len(scene_list):
            index = 0
        scene = scene_list[index]
        if lowmem:
            # If using lowmem, we need to create
            # each scene before performing it.
            this_scene = Scene(screen, scene)
            this_scene.initialize()
            this_scene.perform_scene()
        else:
            scenes[scene].perform_scene()
        
def perform_scene(screen, scene):
    scene = Scene(screen, scene)
    scene.initialize()
    scene.perform_scene()
    
def setup_screen(caption, mode=None):
    if mode is None:
        modes = pygame.display.list_modes()
        mode = max(modes)
    window = pygame.display.set_mode(mode)
    screen = pygame.display.get_surface()
    pygame.display.set_caption(caption)
    return window, screen

